summaryrefslogtreecommitdiffstats
path: root/base
diff options
context:
space:
mode:
authorglider@chromium.org <glider@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-27 15:23:57 +0000
committerglider@chromium.org <glider@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-27 15:23:57 +0000
commitf024242c4d82e8594eade3ce26e6b5d1fdfa092b (patch)
tree845ebc26415e708e801e7f62eedd08466724dfb2 /base
parentaf6dd48f4b5ae2f56790438d83f28ff9ba1c3bd4 (diff)
downloadchromium_src-f024242c4d82e8594eade3ce26e6b5d1fdfa092b.zip
chromium_src-f024242c4d82e8594eade3ce26e6b5d1fdfa092b.tar.gz
chromium_src-f024242c4d82e8594eade3ce26e6b5d1fdfa092b.tar.bz2
Disable the OOM tests under ThreadSanitizer v2 as well as ASan.
BUG=128314 R=mark@chromium.org Review URL: https://codereview.chromium.org/15722004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@202433 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base')
-rw-r--r--base/process_util_unittest.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/base/process_util_unittest.cc b/base/process_util_unittest.cc
index 3ce9942..2d286ca 100644
--- a/base/process_util_unittest.cc
+++ b/base/process_util_unittest.cc
@@ -1069,12 +1069,13 @@ MULTIPROCESS_TEST_MAIN(process_util_test_die_immediately) {
// Android doesn't implement set_new_handler, so we can't use the
// OutOfMemoryTest cases.
// OpenBSD does not support these tests either.
// AddressSanitizer defines the malloc()/free()/etc. functions so that they
// don't crash if the program is out of memory, so the OOM tests aren't supposed
// to work.
// TODO(vandebo) make this work on Windows too.
#if !defined(OS_ANDROID) && !defined(OS_OPENBSD) && \
- !defined(OS_WIN) && !defined(ADDRESS_SANITIZER)
+ !defined(OS_WIN) && \
+ !defined(ADDRESS_SANITIZER) && !defined(THREAD_SANITIZER)
#if defined(USE_TCMALLOC)
extern "C" {
@@ -1069,12 +1069,13 @@ MULTIPROCESS_TEST_MAIN(process_util_test_die_immediately) {
// OutOfMemoryTest cases.
// OpenBSD does not support these tests either.
-// AddressSanitizer defines the malloc()/free()/etc. functions so that they
-// don't crash if the program is out of memory, so the OOM tests aren't supposed
-// to work.
+// AddressSanitizer and ThreadSanitizer define the malloc()/free()/etc.
+// functions so that they don't crash if the program is out of memory, so the
+// OOM tests aren't supposed to work.
// TODO(vandebo) make this work on Windows too.
#if !defined(OS_ANDROID) && !defined(OS_OPENBSD) && \